All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH net-next] psp: rename our psp_dev_destroy()
@ 2025-09-18 11:35 Eric Dumazet
  2025-09-18 11:40 ` Paolo Abeni
                   ` (2 more replies)
  0 siblings, 3 replies; 4+ messages in thread
From: Eric Dumazet @ 2025-09-18 11:35 UTC (permalink / raw)
  To: David S . Miller, Jakub Kicinski, Paolo Abeni
  Cc: Simon Horman, netdev, eric.dumazet, Eric Dumazet, Daniel Zahka,
	Willem de Bruijn

psp_dev_destroy() was already used in drivers/crypto/ccp/psp-dev.c

Use psp_dev_free() instead, to avoid a link error when
CRYPTO_DEV_SP_CCP=y

Fixes: 00c94ca2b99e ("psp: base PSP device support")
Closes: https://lore.kernel.org/netdev/CANn89i+ZdBDEV6TE=Nw5gn9ycTzWw4mZOpPuCswgwEsrgOyNnw@mail.gmail.com/
Signed-off-by: Eric Dumazet <edumazet@google.com>
Cc: Daniel Zahka <daniel.zahka@gmail.com>
Cc: Willem de Bruijn <willemb@google.com>
---
 net/psp/psp.h      | 4 ++--
 net/psp/psp_main.c | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/net/psp/psp.h b/net/psp/psp.h
index 0f34e1a23fdd553861d411c960bc41ebe534a688..9f19137593a03abcf42c5b5f92aae61b1d439e22 100644
--- a/net/psp/psp.h
+++ b/net/psp/psp.h
@@ -13,7 +13,7 @@
 extern struct xarray psp_devs;
 extern struct mutex psp_devs_lock;
 
-void psp_dev_destroy(struct psp_dev *psd);
+void psp_dev_free(struct psp_dev *psd);
 int psp_dev_check_access(struct psp_dev *psd, struct net *net);
 
 void psp_nl_notify_dev(struct psp_dev *psd, u32 cmd);
@@ -42,7 +42,7 @@ static inline bool psp_dev_tryget(struct psp_dev *psd)
 static inline void psp_dev_put(struct psp_dev *psd)
 {
 	if (refcount_dec_and_test(&psd->refcnt))
-		psp_dev_destroy(psd);
+		psp_dev_free(psd);
 }
 
 static inline bool psp_dev_is_registered(struct psp_dev *psd)
diff --git a/net/psp/psp_main.c b/net/psp/psp_main.c
index b4b756f87382c46815f0d74e8b765c962e74eba5..0f8c50c8e94358a060722614a59278320c33134b 100644
--- a/net/psp/psp_main.c
+++ b/net/psp/psp_main.c
@@ -99,7 +99,7 @@ psp_dev_create(struct net_device *netdev,
 }
 EXPORT_SYMBOL(psp_dev_create);
 
-void psp_dev_destroy(struct psp_dev *psd)
+void psp_dev_free(struct psp_dev *psd)
 {
 	mutex_lock(&psp_devs_lock);
 	xa_erase(&psp_devs, psd->id);
@@ -122,7 +122,7 @@ void psp_dev_unregister(struct psp_dev *psd)
 
 	psp_nl_notify_dev(psd, PSP_CMD_DEV_DEL_NTF);
 
 	/* Wait until psp_dev_destroy() to call xa_erase() to prevent a
 	 * different psd from being added to the xarray with this id, while
 	 * there are still references to this psd being held.
 	 */
@@ -122,7 +122,7 @@ void psp_dev_unregister(struct psp_dev *psd)
 	psp_nl_notify_dev(psd, PSP_CMD_DEV_DEL_NTF);
 
-	/* Wait until psp_dev_destroy() to call xa_erase() to prevent a
+	/* Wait until psp_dev_free() to call xa_erase() to prevent a
 	 * different psd from being added to the xarray with this id, while
 	 * there are still references to this psd being held.
-- 
2.51.0.384.g4c02a37b29-goog


^ permalink raw reply related	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2025-09-18 14:30 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2025-09-18 11:35 [PATCH net-next] psp: rename our psp_dev_destroy() Eric Dumazet
2025-09-18 11:40 ` Paolo Abeni
2025-09-18 12:49 ` Daniel Zahka
2025-09-18 14:30 ` patchwork-bot+netdevbpf

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.